{# templates/vty_acl.j2 #}
<h4>======== Verificación de access-class en {{ test }} ========</h4>
<div class="annex-grid">
{% if check %}
        <span class="status-icon status-pass">✓</span>
        <div class="cell">Hay access-class restringiendo el acceso a ciertas IPv4.</div>
{% else %}
        <span class="status-icon status-fail">⚠</span>
        <div class="cell">No hay access-class, cualquier IPv4 tiene acceso.</div>
{% endif %}
</div>