<h2 id="1210"> Anexo </h2>
<p> 
A continuación se detalla lo relevado para los {{ data.cant_tot }}
 dispositivos de la infraestructura de red de <strong>{{ data.empresa }}</strong>. <br />
Es importante hacer notar lo siguiente: <br />
</p>
<ul class="dashed">
<li>Lo que se resalta como <strong>ATENCIÓN!</strong>, significa que
sería deseable tomar una acción correctiva. </li>
<li>Lo que se resalta como <strong>OK!</strong>, significa que
esa funcionalidad del código está con su configuración recomendada.</li>
</ul>
<br />
<div class="annex-style-container">