{# templates/vty_to.j2 #}
<h4>======== Verificación del exec-timout en {{ test }} ========</h4>
<div class="annex-grid">
{% if check %}
        <span class="status-icon status-pass">✓</span>
        <div class="cell">exec-timout tiene un valor distinto al de por defecto.</div>
{% else %}
        <span class="status-icon status-fail">⚠</span>
        <div class="cell">exec-timout tiene valor por defecto.</div>
{% endif %}
</div>